Description Usage Arguments Value See Also Examples
View source: R/classifyNightTrack.R
classifyNightTrack creates labels for the data values
of a Track object marking
a data value as recorded during night or during day. The decision
boundaries are specified by the user.
1 | classifyNightTrack(currenttrack, night)
|
currenttrack |
A |
night |
An integer vector with two elements:
|
A Track object identical to currenttrack
with an attribute night representing a logical vector with a value for
each data value in currenttrack that is TRUE if a data value was
recorded during night and FALSE if it was recorded during day.
#
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.