Description Usage Arguments Value See Also Examples
View source: R/classifyNightTracks.R
classifyNightTracks creates labels for the data values
of a Tracks object with
Track objects with the same time
vectors (i.e. data values for the same time interval) marking
a data value as recorded during night or during day. The decision
boundaries are specified by the user.
1 | classifyNightTracks(currenttracks, night)
|
currenttracks |
A |
night |
An integer vector with two elements:
|
A Tracks object identical to currenttracks
with an attribute night representing a logical vector with a value for
each data value in a Track object in
currenttracks that is TRUE if a data value was recorded during night
and FALSE if it was recorded during day.
#
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.