Description Usage Arguments Value See Also Examples
View source: R/aggregateTrack.R
distancenextvisit_wos computes for a data.frame as created
internally in aggregateTrack the linear distance between locations
of adjacent campsites, whereby short-term visits are counted as gaps.
1 | distancenextvisit_wos(agg, aggcoords)
|
agg |
A |
aggcoords |
A |
A numeric vector containing the linear distance between locations of adjacent campsites,
whereby short-term visits are counted as gaps. Values for a following
move
are always assigned to the last value of a visit in agg as indicated by agg$end.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.