Description Usage Arguments Value See Also Examples
View source: R/extractRasterTracks.R
extractRasterTrack is the extract method
in order to extract values from Raster* objects
for an object of class TracksCollection. Different
options are available.
1 2 3 4 5 6 7 8 9 10 11 12 13 |
x |
A Raster* object. |
y |
A |
datetime |
A POSIXct vector with a date (day) for each layer in |
method |
A character value. |
buffer |
A numeric value indicating the radius of the buffer around each point that should be considered during extraction of the raster values. If the data are not projected (latitude/longitude), the unit should be meters. Otherwise it should be in map-units (typically also meters). |
small |
logical. If |
fun |
function to summarize the values (e.g. |
na.rm |
logical. Only useful when an argument fun is supplied. If
|
fixedlocationcoords |
A logical value indicating if for each location in the
|
cores |
An integer value representing the number of cores to use in parallel computing. |
clcall |
A function that is passed to
|
A vector with a value for each data value of currenttrack.
If a value of raster cannot be assigned to a respective data value,
NA is returned for the respective data value.
extractPolygonsTracks,
extractRasterTrack.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.