Description Usage Arguments Details Value See Also Examples
View source: R/fillGapTracksNight.R
fillGapTracksNight imputes missing values in all
Track objects of the
Tracks objects of a
TracksCollection. Gaps are filled
if their duration is ≤ a user specified duration threshold
and if the distance between the spatial position of the last data
value before the gap and the spatial position of the first data
value after the gap is ≤ a user specified distance threshold.
1 2 3 4 5 6 7 8 | fillGapTracksNight(
currenttracks,
maxduration,
maxdistance,
night = c(16, 20),
cores = 1,
clcall = NULL
)
|
currenttracks |
A |
maxduration |
A numerical value representing the maximum allowed duration of a gap that is filled [s]. |
maxdistance |
A numerical value representing the maximum allowed distance between the spatial position of the last data value before a gap and the spatial position of the first data value after a gap that is filled [m]. |
night |
An integer vector with two elements:
|
cores |
An integer value representing the number of cores to use in parallel computing. |
clcall |
A function that is passed to
|
It has to be paid
attention to the fact that maxduration should be adapted to
the time interval specified by night. For example, if one specifies
the time interval between 0 and 4 o' clock as night and wants to allow
a maxduration of four days (assuming that there may be gaps for four
following nights, but if there is no gap in the fifth night, then the gap is
filled), then one must specifiy maxduration as
4*24*60*60 + (24 - nightduration)*60*60, whereby nightduration
is the duration of the time interval specified as night in hours.
The input Tracks object with filled
gaps.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.