Description Usage Arguments Value Examples
View source: R/identifyBlocksVariable.R
identifyBlocksVariable identifies blocks of rows in the
data slot of a Track object
or data.frame object
based on a grouping variable and a value for this variable. A
block is defined as a set of directly subsequent rows with the
same value for the specified variable.
1 | identifyBlocksVariable(currenttrack, variable, value)
|
currenttrack |
A |
variable |
A character value indicating the name of a
variable in |
value |
A value of the |
A matrix with two columns and rows for each identified
block. The first column indicates the row of currenttrack@data
where the block begins and the second column indicates the row of
currenttrack@data where the block ends or NULL if
value does not exist for variable.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.