mergeTracksCollection: Merges 'Track' objects of a 'Tracks' objects.

Description Usage Arguments Value See Also Examples

View source: R/mergeTracksCollection.R

Description

mergeTracksCollection merges the Track objects for each Tracks object of a TracksCollection into a singular Track object.

Usage

1
mergeTracksCollection(trackscollection, cores = 1, clcall = NULL)

Arguments

trackscollection

A TracksCollection object.

cores

An integer value representing the number of cores to use in parallel computing.

clcall

A function that is passed to clusterCall.

Value

A TracksCollection object with a Tracks object for each former Tracks object containing the merged Track objects of the input Tracks object as one Track object.

See Also

mergeTracks, reorganizeTracks.

Examples

1
#

henningte/herdersTA documentation built on Jan. 22, 2020, 5:16 a.m.