removeEmptyFiles: Finds non-empty .csv files in a directory.

Description Usage Arguments Value See Also Examples

View source: R/removeEmptyFiles.R

Description

removeEmptyFiles returns the names of non-empty .csv files within a directory by ignoring empty .csv files.

Usage

1
removeEmptyFiles(listname)

Arguments

listname

A list of file names of the correpsonding GPS track files that should be chekced.

Value

A list of file names of the correpsonding GPS track files that are not empty.

See Also

readTrack, removeEmptyFolders.

Examples

1
#

henningte/herdersTA documentation built on Jan. 22, 2020, 5:16 a.m.