Description Usage Arguments Details Value See Also Examples
View source: R/reorganizeTracks.R
reorganizeTracks reorganises a TracksCollection
object with each Tracks object containing one
Track object. The
Track objects
covering roughly the same time period are reorganised by assigning data points to
the same overall time vector with half-hourly spaced data and including gaps as
new data points within each Track object.
Gaps are filled with dummy values from the next value prior the gap or if there is
an ending gap, with the next value prior the ending gap.
1 2 3 4 5 6 7 8 | reorganizeTracks(
currenttracks,
interval = 60 * 30,
tz = "GMT",
crs = "+proj=longlat +ellps=WGS84",
cores = 1,
clcall = NULL
)
|
currenttracks |
A |
interval |
A numeric value > 0 representing the duration of each time interval
the data are reorganised to [s]. The deault is |
tz |
A character value indicating the time zone of the data in |
crs |
A character value indicating the coordinate reference system of |
cores |
An integer value representing the number of cores to use in parallel computing. |
clcall |
A function that is passed to
|
If there are more than one data point per interval and
Track object, only the first data
point within this interval is retained.
A Tracks object containing
the reorganised Track objects of the
input A Tracks object.
mergeTracksCollection, mergeTracks.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.