Description Usage Arguments Value See Also Examples
View source: R/trackvisitsMergeGroups.R
trackvisitsMergeGroups merges groups of visits at the same location.
For this, an object of class trackvisits has to be processed
with trackvisitsGetGroups first or the variable
trackvisits$group has to be defined as desired.
1 2 3 4 5 6 | trackvisitsMergeGroups(
currenttrackvisits,
tmin,
timeinterval = 30 * 60,
keepgroup = FALSE
)
|
currenttrackvisits |
An object of class |
tmin |
The minimum residence time at a specific location [s]
which is used to classify visits as campsites (if the residence
time at a specific location is larger than |
timeinterval |
The number of seconds one data value (row) in
|
keepgroup |
A logical value indicating if the input group values should
be retained for each group ( |
An object of class trackvisits in which all
visits belonging to the same group are merged into one visit. The variables
of currenttrackvisits are changed as:
locationnot changed (location of the first visit of the group).
groupif keepgroup = TRUE, the respective input group value,
if keepgroup = FALSE reset to NA.
startvalue of start of the first visit of the group.
endvalue of end of the last visit of the group.
starttimevalue of starttime of the first visit of the group.
endtimevalue of endtime of the last visit of the group.
currentvisitdurationupdated.
nextvisitdurationupdated.
nextvisitsamelocationdurationupdated.
nextvisitsamelocationupdated.
campsiteupdated.
campsiteinbetweenupdated.
mergewithnextreset to NA.
trackvisits,
plot.trackvisits,
trackvisitsFromTrack,
trackvisitsGetGroups,
trackvisitsSetNextvisitsamelocationindex,
trackvisitsSetNorepeatedcampsitevisits.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.