trackvisitsSetNorepeatedcampsitevisits: Get the Number of Repeated Campsite Visits.

Description Usage Arguments Value See Also Examples

View source: R/trackvisitsSetNorepeatedcampsitevisits.R

Description

trackvisitsSetNorepeatedcampsitevisits sets the number of repeated campsite visits for each location of an object of class trackvisits. A visit is a repeated campsite visit if (1) it is a campsite visit and (2) the previous visit is at a different location.

Usage

1

Arguments

currenttrackvisits

An object of class trackvisits for which the variables campsite and nextvisitsamelocation are defined.

Value

An object of class trackvisits in which the number of repeated campsite visits at the same location is set.

See Also

trackvisits, plot.trackvisits, trackvisitsFromTrack, trackvisitsGetGroups, trackvisitsMergeGroups, trackvisitsSetNextvisitsamelocationindex.

Examples

1
#

henningte/herdersTA documentation built on Jan. 22, 2020, 5:16 a.m.