Description Usage Arguments Value See Also Examples
View source: R/removeEmptyFiles.R
removeEmptyFiles returns the names of non-empty .csv files within a
directory by ignoring empty .csv files.
1 | removeEmptyFiles(listname)
|
listname |
A list of file names of the correpsonding GPS track files that should be chekced. |
A list of file names of the correpsonding GPS track files that are not empty.
readTrack, removeEmptyFolders.
1 | #
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.